package
Version:
v0.0.0-...-ecb2b82
Opens a new window with list of versions in this module.
Published: May 7, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
New returns a new compiler.
Generate generates code for the given source path.
type Options struct {
SkipRPC bool
}
Source Files
¶
Directories
¶
internal
|
|
|
|
|
|
|
|
|
|
|
|
|
|
parser
Code generated by goyacc -l -v grammar.out -o grammar.go grammar.y.
|
Code generated by goyacc -l -v grammar.out -o grammar.go grammar.y. |
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
Click to show internal directories.
Click to hide internal directories.